:orphan:

Pygame Colors
=============

Below is a list of the 140 colour names supported in Pygame [1]_ .



Reds
----

.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #8b0000;
                border-color: #450000">
        darkred<br>
        <code>#8b0000</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #a52a2a;
                border-color: #521515">
        brown<br>
        <code>#a52a2a</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #b22222;
                border-color: #591111">
        firebrick<br>
        <code>#b22222</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #bc8f8f;
                border-color: #5e4747">
        rosybrown<br>
        <code>#bc8f8f</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #cd5c5c;
                border-color: #662e2e">
        indianred<br>
        <code>#cd5c5c</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f08080;
                border-color: #784040">
        lightcoral<br>
        <code>#f08080</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fffafa;
                border-color: #807d7d">
        snow<br>
        <code>#fffafa</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #ff0000;
                border-color: #800000">
        red<br>
        <code>#ff0000</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffe4e1;
                border-color: #807270">
        mistyrose<br>
        <code>#ffe4e1</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fa8072;
                border-color: #7d4039">
        salmon<br>
        <code>#fa8072</code>
    </div>



Oranges
-------

.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ff6347;
                border-color: #803123">
        tomato<br>
        <code>#ff6347</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #e9967a;
                border-color: #744b3d">
        darksalmon<br>
        <code>#e9967a</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ff7f50;
                border-color: #803f28">
        coral<br>
        <code>#ff7f50</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #ff4500;
                border-color: #802200">
        orangered<br>
        <code>#ff4500</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffa07a;
                border-color: #80503d">
        lightsalmon<br>
        <code>#ffa07a</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #a0522d;
                border-color: #502916">
        sienna<br>
        <code>#a0522d</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fff5ee;
                border-color: #807a77">
        seashell<br>
        <code>#fff5ee</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #8b4513;
                border-color: #452209">
        saddlebrown<br>
        <code>#8b4513</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #d2691e;
                border-color: #69340f">
        chocolate<br>
        <code>#d2691e</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f4a460;
                border-color: #7a5230">
        sandybrown<br>
        <code>#f4a460</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffdab9;
                border-color: #806d5c">
        peachpuff<br>
        <code>#ffdab9</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #cd853f;
                border-color: #66421f">
        peru<br>
        <code>#cd853f</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #faf0e6;
                border-color: #7d7873">
        linen<br>
        <code>#faf0e6</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffe4c4;
                border-color: #807262">
        bisque<br>
        <code>#ffe4c4</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ff8c00;
                border-color: #804600">
        darkorange<br>
        <code>#ff8c00</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #deb887;
                border-color: #6f5c43">
        burlywood<br>
        <code>#deb887</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #faebd7;
                border-color: #7d756b">
        antiquewhite<br>
        <code>#faebd7</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #d2b48c;
                border-color: #695a46">
        tan<br>
        <code>#d2b48c</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffdead;
                border-color: #806f56">
        navajowhite<br>
        <code>#ffdead</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffebcd;
                border-color: #807566">
        blanchedalmond<br>
        <code>#ffebcd</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffefd5;
                border-color: #80776a">
        papayawhip<br>
        <code>#ffefd5</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffe4b5;
                border-color: #80725a">
        moccasin<br>
        <code>#ffe4b5</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffa500;
                border-color: #805200">
        orange<br>
        <code>#ffa500</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f5deb3;
                border-color: #7a6f59">
        wheat<br>
        <code>#f5deb3</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fdf5e6;
                border-color: #7e7a73">
        oldlace<br>
        <code>#fdf5e6</code>
    </div>



Yellows
-------

.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fffaf0;
                border-color: #807d78">
        floralwhite<br>
        <code>#fffaf0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #b8860b;
                border-color: #5c4305">
        darkgoldenrod<br>
        <code>#b8860b</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #daa520;
                border-color: #6d5210">
        goldenrod<br>
        <code>#daa520</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fff8dc;
                border-color: #807c6e">
        cornsilk<br>
        <code>#fff8dc</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #eedd82;
                border-color: #776e41">
        lightgoldenrod<br>
        <code>#eedd82</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffd700;
                border-color: #806b00">
        gold<br>
        <code>#ffd700</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fffacd;
                border-color: #807d66">
        lemonchiffon<br>
        <code>#fffacd</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f0e68c;
                border-color: #787346">
        khaki<br>
        <code>#f0e68c</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #eee8aa;
                border-color: #777455">
        palegoldenrod<br>
        <code>#eee8aa</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #bdb76b;
                border-color: #5e5b35">
        darkkhaki<br>
        <code>#bdb76b</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #808000;
                border-color: #404000">
        olive<br>
        <code>#808000</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f5f5dc;
                border-color: #7a7a6e">
        beige<br>
        <code>#f5f5dc</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fafad2;
                border-color: #7d7d69">
        lightgoldenrodyellow<br>
        <code>#fafad2</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fffff0;
                border-color: #808078">
        ivory<br>
        <code>#fffff0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffffe0;
                border-color: #808070">
        lightyellow<br>
        <code>#ffffe0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffff00;
                border-color: #808000">
        yellow<br>
        <code>#ffff00</code>
    </div>



Greens
------

.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #6b8e23;
                border-color: #354711">
        olivedrab<br>
        <code>#6b8e23</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #9acd32;
                border-color: #4d6619">
        yellowgreen<br>
        <code>#9acd32</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #556b2f;
                border-color: #2a3517">
        darkolivegreen<br>
        <code>#556b2f</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #adff2f;
                border-color: #568017">
        greenyellow<br>
        <code>#adff2f</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #7fff00;
                border-color: #3f8000">
        chartreuse<br>
        <code>#7fff00</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #7cfc00;
                border-color: #3e7e00">
        lawngreen<br>
        <code>#7cfc00</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #006400;
                border-color: #003200">
        darkgreen<br>
        <code>#006400</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #228b22;
                border-color: #114511">
        forestgreen<br>
        <code>#228b22</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #8fbc8f;
                border-color: #475e47">
        darkseagreen<br>
        <code>#8fbc8f</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #32cd32;
                border-color: #196619">
        limegreen<br>
        <code>#32cd32</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #90ee90;
                border-color: #487748">
        lightgreen<br>
        <code>#90ee90</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #98fb98;
                border-color: #4c7d4c">
        palegreen<br>
        <code>#98fb98</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f0fff0;
                border-color: #788078">
        honeydew<br>
        <code>#f0fff0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #00ff00;
                border-color: #008000">
        green / lime<br>
        <code>#00ff00</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #2e8b57;
                border-color: #17452b">
        seagreen<br>
        <code>#2e8b57</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #3cb371;
                border-color: #1e5938">
        mediumseagreen<br>
        <code>#3cb371</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #00ff7f;
                border-color: #00803f">
        springgreen<br>
        <code>#00ff7f</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f5fffa;
                border-color: #7a807d">
        mintcream<br>
        <code>#f5fffa</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #00fa9a;
                border-color: #007d4d">
        mediumspringgreen<br>
        <code>#00fa9a</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #66cdaa;
                border-color: #336655">
        mediumaquamarine<br>
        <code>#66cdaa</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #7fffd4;
                border-color: #3f806a">
        aquamarine<br>
        <code>#7fffd4</code>
    </div>



Turquoises
----------

.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #40e0d0;
                border-color: #207068">
        turquoise<br>
        <code>#40e0d0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #20b2aa;
                border-color: #105955">
        lightseagreen<br>
        <code>#20b2aa</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #48d1cc;
                border-color: #246866">
        mediumturquoise<br>
        <code>#48d1cc</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #2f4f4f;
                border-color: #172727">
        darkslategray / darkslategrey<br>
        <code>#2f4f4f</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #008080;
                border-color: #004040">
        teal<br>
        <code>#008080</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #008b8b;
                border-color: #004545">
        darkcyan<br>
        <code>#008b8b</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #afeeee;
                border-color: #577777">
        paleturquoise<br>
        <code>#afeeee</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f0ffff;
                border-color: #788080">
        azure<br>
        <code>#f0ffff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #e0ffff;
                border-color: #708080">
        lightcyan<br>
        <code>#e0ffff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #00ffff;
                border-color: #008080">
        aqua / cyan<br>
        <code>#00ffff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #00ced1;
                border-color: #006768">
        darkturquoise<br>
        <code>#00ced1</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #5f9ea0;
                border-color: #2f4f50">
        cadetblue<br>
        <code>#5f9ea0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #b0e0e6;
                border-color: #587073">
        powderblue<br>
        <code>#b0e0e6</code>
    </div>



Blues
-----

.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #add8e6;
                border-color: #566c73">
        lightblue<br>
        <code>#add8e6</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #00bfff;
                border-color: #005f80">
        deepskyblue<br>
        <code>#00bfff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #87ceeb;
                border-color: #436775">
        skyblue<br>
        <code>#87ceeb</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #87cefa;
                border-color: #43677d">
        lightskyblue<br>
        <code>#87cefa</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #4682b4;
                border-color: #23415a">
        steelblue<br>
        <code>#4682b4</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f0f8ff;
                border-color: #787c80">
        aliceblue<br>
        <code>#f0f8ff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #1e90ff;
                border-color: #0f4880">
        dodgerblue<br>
        <code>#1e90ff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #708090;
                border-color: #384048">
        slategray / slategrey<br>
        <code>#708090</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #778899;
                border-color: #3b444c">
        lightslategray / lightslategrey<br>
        <code>#778899</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #b0c4de;
                border-color: #58626f">
        lightsteelblue<br>
        <code>#b0c4de</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #6495ed;
                border-color: #324a76">
        cornflowerblue<br>
        <code>#6495ed</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #4169e1;
                border-color: #203470">
        royalblue<br>
        <code>#4169e1</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #191970;
                border-color: #0c0c38">
        midnightblue<br>
        <code>#191970</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #000080;
                border-color: #000040">
        navy / navyblue<br>
        <code>#000080</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #00008b;
                border-color: #000045">
        darkblue<br>
        <code>#00008b</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #0000cd;
                border-color: #000066">
        mediumblue<br>
        <code>#0000cd</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #e6e6fa;
                border-color: #73737d">
        lavender<br>
        <code>#e6e6fa</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f8f8ff;
                border-color: #7c7c80">
        ghostwhite<br>
        <code>#f8f8ff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #0000ff;
                border-color: #000080">
        blue<br>
        <code>#0000ff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #6a5acd;
                border-color: #352d66">
        slateblue<br>
        <code>#6a5acd</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #8470ff;
                border-color: #423880">
        lightslateblue<br>
        <code>#8470ff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #483d8b;
                border-color: #241e45">
        darkslateblue<br>
        <code>#483d8b</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #7b68ee;
                border-color: #3d3477">
        mediumslateblue<br>
        <code>#7b68ee</code>
    </div>



Purples
-------

.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #9370db;
                border-color: #49386d">
        mediumpurple<br>
        <code>#9370db</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #8a2be2;
                border-color: #451571">
        blueviolet<br>
        <code>#8a2be2</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #4b0082;
                border-color: #250041">
        indigo<br>
        <code>#4b0082</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #a020f0;
                border-color: #501078">
        purple<br>
        <code>#a020f0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #9932cc;
                border-color: #4c1966">
        darkorchid<br>
        <code>#9932cc</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #9400d3;
                border-color: #4a0069">
        darkviolet<br>
        <code>#9400d3</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ba55d3;
                border-color: #5d2a69">
        mediumorchid<br>
        <code>#ba55d3</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #8b008b;
                border-color: #450045">
        darkmagenta<br>
        <code>#8b008b</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #d8bfd8;
                border-color: #6c5f6c">
        thistle<br>
        <code>#d8bfd8</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #dda0dd;
                border-color: #6e506e">
        plum<br>
        <code>#dda0dd</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ee82ee;
                border-color: #774177">
        violet<br>
        <code>#ee82ee</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #ff00ff;
                border-color: #800080">
        fuchsia / magenta<br>
        <code>#ff00ff</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #da70d6;
                border-color: #6d386b">
        orchid<br>
        <code>#da70d6</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #d02090;
                border-color: #681048">
        violetred<br>
        <code>#d02090</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #c71585;
                border-color: #630a42">
        mediumvioletred<br>
        <code>#c71585</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #ff1493;
                border-color: #800a49">
        deeppink<br>
        <code>#ff1493</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ff69b4;
                border-color: #80345a">
        hotpink<br>
        <code>#ff69b4</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #b03060;
                border-color: #581830">
        maroon<br>
        <code>#b03060</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #fff0f5;
                border-color: #80787a">
        lavenderblush<br>
        <code>#fff0f5</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #db7093;
                border-color: #6d3849">
        palevioletred<br>
        <code>#db7093</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #dc143c;
                border-color: #6e0a1e">
        crimson<br>
        <code>#dc143c</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffc0cb;
                border-color: #806065">
        pink<br>
        <code>#ffc0cb</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffb6c1;
                border-color: #805b60">
        lightpink<br>
        <code>#ffb6c1</code>
    </div>



Greys
-----

.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #000000;
                border-color: #000000">
        black<br>
        <code>#000000</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: white; background-color: #696969;
                border-color: #343434">
        dimgray / dimgrey<br>
        <code>#696969</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #a9a9a9;
                border-color: #545454">
        darkgray / darkgrey<br>
        <code>#a9a9a9</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #bebebe;
                border-color: #5f5f5f">
        gray / grey<br>
        <code>#bebebe</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #c0c0c0;
                border-color: #606060">
        silver<br>
        <code>#c0c0c0</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #d3d3d3;
                border-color: #696969">
        lightgray / lightgrey<br>
        <code>#d3d3d3</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #dcdcdc;
                border-color: #6e6e6e">
        gainsboro<br>
        <code>#dcdcdc</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #f5f5f5;
                border-color: #7a7a7a">
        whitesmoke<br>
        <code>#f5f5f5</code>
    </div>


.. raw:: html

    <div class="color-swatch"
         style="color: black; background-color: #ffffff;
                border-color: #808080">
        white<br>
        <code>#ffffff</code>
    </div>



.. [1] In fact, many of these names have additional fine variations with
       digits appended, eg. ``antiquewhite1``. Because the differences are small, and
       there are so many colours without these, these variants have been
       omitted here.

